VideoPlayerPlatform class abstract
The interface that implementations of video_player must implement.
Platform implementations should extend this class rather than implement it as video_player
does not consider newly added methods to be breaking changes. Extending this class
(using extends) ensures that the subclass will get the default implementation, while
platform implementations that implements this interface will be broken by newly added
VideoPlayerPlatform methods.
- Implementers
Constructors
Properties
Methods
-
create(
DataSource? dataSource) → Future< int?> - Creates an instance of a video player and returns its textureId.
-
dispose(
int? textureId) → Future< void> - Clears one video.
-
getPosition(
int? textureId) → Future< Duration> - Gets the video position as Duration from the start.
-
init(
) → Future< void> - Initializes the platform interface and disposes all existing players.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
int? textureId) → Future< void> - Stops the video playback.
-
play(
int? textureId) → Future< void> - Starts the video playback.
-
seekTo(
int? textureId, Duration? position) → Future< void> - Sets the video position to a Duration from the start.
-
setLooping(
int? textureId, bool looping) → Future< void> - Sets the looping attribute of the video.
-
setMuted(
int? textureId, bool muted) → Future< void> - Sets the muted attribute of the video.
-
setVolume(
int? textureId, double volume) → Future< void> - Sets the volume to a range between 0.0 and 1.0.
-
toString(
) → String -
A string representation of this object.
inherited
-
videoEventsFor(
int? textureId) → Stream< VideoEvent> - Returns a Stream of VideoEventTypes.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ VideoPlayerPlatform
-
The default instance of VideoPlayerPlatform to use.
getter/setter pair